@@ -18,11 +18,25 @@ except:
 
 
 
+class MyProtoTest(ProtoTest):
+    """
+    For quickly making a ProtoTest
+    """
+    def __init__(self):
+        self.module      = "my_module"
+        self.class_name  = "MyClass"
+        self.method_name = "myMethod"
+        self.docstr_part = "My docstring"
+
+
+
 class TestProtoTestResult(unittest.TestCase):
 
 
     def test_addSuccess(self):
-        "addSuccess adds a test correctly"
+        """
+        addSuccess adds a test correctly
+        """
         ptr = ProtoTestResult()
         test = proto_test(MagicMock())
         ptr.addSuccess(test)
@@ -30,7 +44,9 @@ class TestProtoTestResult(unittest.TestCase):
 
 
     def test_addError(self):
-        "addError adds a test and error correctly"
+        """
+        addError adds a test and error correctly
+        """
         ptr = ProtoTestResult()
         test = proto_test(MagicMock())
         try:
@@ -43,7 +59,9 @@ class TestProtoTestResult(unittest.TestCase):
 
 
     def test_addFailure(self):
-        "addFailure adds a test and error correctly"
+        """
+        addFailure adds a test and error correctly
+        """
         ptr = ProtoTestResult()
         test = proto_test(MagicMock())
         try:
@@ -56,7 +74,9 @@ class TestProtoTestResult(unittest.TestCase):
 
 
     def test_addSkip(self):
-        "addSkip adds a test and reason correctly"
+        """
+        addSkip adds a test and reason correctly
+        """
         ptr = ProtoTestResult()
         test = proto_test(MagicMock())
         reason = "some plausible reason"
@@ -66,7 +86,9 @@ class TestProtoTestResult(unittest.TestCase):
 
 
     def test_addExpectedFailure(self):
-        "addExpectedFailure adds a test and error correctly"
+        """
+        addExpectedFailure adds a test and error correctly
+        """
         ptr = ProtoTestResult()
         test = proto_test(MagicMock())
         try:
@@ -79,7 +101,9 @@ class TestProtoTestResult(unittest.TestCase):
 
 
     def test_addUnexpectedSuccess(self):
-        "addUnexpectedSuccess adds a test correctly"
+        """
+        addUnexpectedSuccess adds a test correctly
+        """
         ptr = ProtoTestResult()
         test = proto_test(MagicMock())
         ptr.addUnexpectedSuccess(test)
@@ -91,14 +115,18 @@ class TestProtoTest(unittest.TestCase):
 
 
     def test_ProtoTestBlank(self):
-        "ProtoTest can be instantiated empty"
+        """
+        ProtoTest can be instantiated empty
+        """
         pt = ProtoTest()
         for i in ['module', 'class_name', 'docstr_part', 'method_name']:
             self.assertEqual('', getattr(pt, i, None))
 
 
     def test_ProtoTestFromTest(self):
-        "Passing a test into ProtoTest copies out the relevant info."
+        """
+        Passing a test into ProtoTest copies out the relevant info.
+        """
         module      = 'green.test.test_result'
         class_name  = 'Small'
         docstr_part = 'stuff'
@@ -114,7 +142,9 @@ class TestProtoTest(unittest.TestCase):
 
 
     def test_getDescription(self):
-        "getDescription() returns what we expect for all verbosity levels"
+        """
+        getDescription() returns what we expect for all verbosity levels
+        """
         # With a docstring
         class Fruit(unittest.TestCase):
             def test_stuff(self):
@@ -138,7 +168,9 @@ class TestProtoTest(unittest.TestCase):
 
 
     def test_newlineDocstring(self):
-        "Docstrings starting with a newline are properly handled."
+        """
+        Docstrings starting with a newline are properly handled.
+        """
         class MyTests(unittest.TestCase):
             def test_stuff(self):
                 """
@@ -150,7 +182,9 @@ class TestProtoTest(unittest.TestCase):
 
 
     def test_multilineDocstring(self):
-        "The description includes all of docstring until the first blank line."
+        """
+        The description includes all of docstring until the first blank line.
+        """
         class LongDocs(unittest.TestCase):
             def test_long(self):
                 """First line is
@@ -177,7 +211,9 @@ class TestGreenTestResult(unittest.TestCase):
 
 
     def test_startTestVerbose(self):
-        "startTest() contains output we expect in verbose mode"
+        """
+        startTest() contains output we expect in verbose mode
+        """
         class FakeCase(unittest.TestCase):
             def runTest(self):
                 pass
@@ -191,30 +227,36 @@ class TestGreenTestResult(unittest.TestCase):
         #   FakeCase
         #     test_it
         self.assertEqual(len(output_lines), 3)
-        self.assertFalse(' ' in output_lines[0])
-        self.assertTrue('  ' in output_lines[1])
-        self.assertTrue('    ' in output_lines[2])
+        self.assertNotIn(' ', output_lines[0])
+        self.assertIn('  ', output_lines[1])
+        self.assertIn('    ', output_lines[2])
 
 
     def test_reportOutcome(self):
-        "_reportOutcome contains output we expect"
+        """
+        _reportOutcome contains output we expect
+        """
         gtr = GreenTestResult(GreenStream(self.stream), None, 1)
         gtr._reportOutcome(None, '.', lambda x: x)
-        self.assertTrue('.' in self.stream.getvalue())
+        self.assertIn('.', self.stream.getvalue())
 
 
     def test_reportOutcomeVerbose(self):
-        "_reportOutcome contains output we expect in verbose mode"
+        """
+        _reportOutcome contains output we expect in verbose mode
+        """
         gtr = GreenTestResult(GreenStream(self.stream), None, 2)
         r = 'a fake reason'
         t = MagicMock()
         t.__str__.return_value = 'junk'
         gtr._reportOutcome(t, '.', lambda x: x, None, r)
-        self.assertTrue(r in self.stream.getvalue())
+        self.assertIn(r, self.stream.getvalue())
 
 
     def test_reportOutcomeVerboseHTML(self):
-        "html=True causes _reportOutcome() to escape HTML in docstrings"
+        """
+        html=True causes _reportOutcome() to escape HTML in docstrings
+        """
         gtr = GreenTestResult(GreenStream(self.stream), None, 3)
         gtr.colors.html = True
         r = 'a fake reason'
@@ -233,79 +275,104 @@ class TestGreenTestResult(unittest.TestCase):
 
 
     def test_printErrorsDots(self):
-        "printErrors() looks correct in verbose=1 (dots) mode"
+        """
+        printErrors() looks correct in verbose=1 (dots) mode
+        """
         try:
             raise Exception
         except:
             err = sys.exc_info()
-        gtr = GreenTestResult(GreenStream(self.stream), None, 1)
-        test = MagicMock()
-        gtr.addError(test, proto_error(err))
+        gtr = GreenTestResult(GreenStream(self.stream), None, 1, False, False)
+        gtr.addError(MyProtoTest(), proto_error(err))
         gtr.printErrors()
-        self.assertTrue('\n\n' in self.stream.getvalue())
-        self.assertTrue('test_printErrorsDots' in self.stream.getvalue())
-        self.assertTrue('raise Exception' in self.stream.getvalue())
-        self.assertTrue('Error' in self.stream.getvalue())
+        self.assertIn('\n\n', self.stream.getvalue())
+        self.assertIn('my_module.MyClass.myMethod', self.stream.getvalue())
+        self.assertIn('test_printErrorsDots', self.stream.getvalue())
+        self.assertIn('raise Exception', self.stream.getvalue())
+        self.assertIn('Error', self.stream.getvalue())
 
 
     def test_printErrorsVerbose2(self):
-        "printErrors() looks correct in verbose=2 mode"
+        """
+        printErrors() looks correct in verbose=2 mode
+        """
         try:
             raise Exception
         except:
             err = sys.exc_info()
-        gtr = GreenTestResult(GreenStream(self.stream), None, 2)
-        gtr.test_output_line = "   some test output"
-        test = MagicMock()
-        gtr.addError(test, proto_error(err))
+        gtr = GreenTestResult(GreenStream(self.stream), None, 2, False, False)
+        gtr.addError(MyProtoTest(), proto_error(err))
         gtr.printErrors()
-        self.assertTrue('\n\n' in self.stream.getvalue())
-        self.assertTrue('test_printErrorsVerbose2' in self.stream.getvalue())
-        self.assertTrue('raise Exception' in self.stream.getvalue())
-        self.assertTrue('Error' in self.stream.getvalue())
+        self.assertIn('\n\n', self.stream.getvalue())
+        self.assertIn('my_module.MyClass.myMethod', self.stream.getvalue())
+        self.assertIn('test_printErrorsVerbose2', self.stream.getvalue())
+        self.assertIn('raise Exception', self.stream.getvalue())
+        self.assertIn('Error', self.stream.getvalue())
+
+
+    def test_printErrorsVerbose3(self):
+        """
+        printErrors() looks correct in verbose=3 mode
+        """
+        try:
+            raise Exception
+        except:
+            err = sys.exc_info()
+        gtr = GreenTestResult(GreenStream(self.stream), None, 3, False, False)
+        gtr.addError(MyProtoTest(), proto_error(err))
+        gtr.printErrors()
+        self.assertIn('\n\n', self.stream.getvalue())
+        self.assertIn('my_module.MyClass.myMethod', self.stream.getvalue())
+        self.assertIn('test_printErrorsVerbose3', self.stream.getvalue())
+        self.assertIn('raise Exception', self.stream.getvalue())
+        self.assertIn('Error', self.stream.getvalue())
 
 
     def test_printErrorsVerbose4(self):
-        "printErrors() looks correct in verbose=4 mode"
+        """
+        printErrors() looks correct in verbose=4 mode
+        """
         try:
             raise Exception
         except:
             err = sys.exc_info()
-        gtr = GreenTestResult(GreenStream(self.stream), None, 4)
-        gtr.test_output_line = "   some test output"
-        test = MagicMock()
-        gtr.addError(test, err)
+        gtr = GreenTestResult(GreenStream(self.stream), None, 4, False, False)
+        gtr.addError(MyProtoTest(), err)
         gtr.printErrors()
-        self.assertTrue('\n\n' in self.stream.getvalue())
-        self.assertTrue('(most recent call last)' in self.stream.getvalue())
-        self.assertTrue('test_printErrorsVerbose4' in self.stream.getvalue())
-        self.assertTrue('raise Exception' in self.stream.getvalue())
-        self.assertTrue('Error' in self.stream.getvalue())
+        self.assertIn('\n\n', self.stream.getvalue())
+        self.assertIn('(most recent call last)', self.stream.getvalue())
+        self.assertIn('my_module.MyClass.myMethod', self.stream.getvalue())
+        self.assertIn('test_printErrorsVerbose4', self.stream.getvalue())
+        self.assertIn('raise Exception', self.stream.getvalue())
+        self.assertIn('Error', self.stream.getvalue())
 
 
     def test_printErrorsZHTML(self):
-        "printErrors() looks correct in html mode"
+        """
+        printErrors() looks correct in html mode
+        """
         try:
             raise Exception
         except:
             err = sys.exc_info()
         gtr = GreenTestResult(GreenStream(self.stream), None, 4)
         gtr.colors.html = True
-        gtr.test_output_line = "   some test output"
         test = MagicMock()
         gtr.addError(test, proto_error(err))
         gtr.printErrors()
-        self.assertTrue('\n\n' in self.stream.getvalue())
-        self.assertTrue('(most recent call last)' in self.stream.getvalue())
-        self.assertTrue('test_printErrorsZHTML' in self.stream.getvalue())
-        self.assertTrue('raise Exception' in self.stream.getvalue())
-        self.assertTrue('Error' in self.stream.getvalue())
-        self.assertTrue('<span' in self.stream.getvalue())
-        self.assertTrue('color: rgb(' in self.stream.getvalue())
+        self.assertIn('\n\n', self.stream.getvalue())
+        self.assertIn('(most recent call last)', self.stream.getvalue())
+        self.assertIn('test_printErrorsZHTML', self.stream.getvalue())
+        self.assertIn('raise Exception', self.stream.getvalue())
+        self.assertIn('Error', self.stream.getvalue())
+        self.assertIn('<span', self.stream.getvalue())
+        self.assertIn('color: rgb(', self.stream.getvalue())
 
 
     def test_addProtoTestResult(self):
-        "addProtoTestResult adds the correct things to the correct places"
+        """
+        addProtoTestResult adds the correct things to the correct places
+        """
         ptr = ProtoTestResult()
 
         err_t = proto_test(MagicMock())
@@ -366,7 +433,9 @@ class TestGreenTestResultAdds(unittest.TestCase):
 
 
     def test_addSuccess(self):
-        "addSuccess() makes the correct calls to other functions."
+        """
+        addSuccess() makes the correct calls to other functions.
+        """
         test = MagicMock()
         test.shortDescription.return_value = 'a'
         test.__str__.return_value = 'b'
@@ -377,7 +446,9 @@ class TestGreenTestResultAdds(unittest.TestCase):
 
 
     def test_addError(self):
-        "addError() makes the correct calls to other functions."
+        """
+        addError() makes the correct calls to other functions.
+        """
         try:
             raise Exception
         except:
@@ -390,7 +461,9 @@ class TestGreenTestResultAdds(unittest.TestCase):
 
 
     def test_addFailure(self):
-        "addFailure() makes the correct calls to other functions."
+        """
+        addFailure() makes the correct calls to other functions.
+        """
         err = None
         try:
             raise Exception
@@ -404,7 +477,9 @@ class TestGreenTestResultAdds(unittest.TestCase):
 
 
     def test_addSkip(self):
-        "addSkip() makes the correct calls to other functions."
+        """
+        addSkip() makes the correct calls to other functions.
+        """
         test = proto_test(MagicMock())
         reason = 'skip reason'
         self.gtr.addSkip(test, reason)
@@ -413,7 +488,9 @@ class TestGreenTestResultAdds(unittest.TestCase):
 
 
     def test_addExpectedFailure(self):
-        "addExpectedFailure() makes the correct calls to other functions."
+        """
+        addExpectedFailure() makes the correct calls to other functions.
+        """
         try:
             raise Exception
         except:
@@ -426,7 +503,9 @@ class TestGreenTestResultAdds(unittest.TestCase):
 
 
     def test_addUnexpectedSuccess(self):
-        "addUnexpectedSuccess() makes the correct calls to other functions."
+        """
+        addUnexpectedSuccess() makes the correct calls to other functions.
+        """
         test = proto_test(MagicMock())
         self.gtr.addUnexpectedSuccess(test)
         self.gtr._reportOutcome.assert_called_with(
